@@ -2,10 +2,11 @@
 
 from typing import Iterator, Type, Union, Iterable, Optional
 
+from onapsdk.exceptions import StatusError, ParameterError
 from onapsdk.sdc.service import Service
 from onapsdk.so.deletion import ServiceDeletionRequest
 from onapsdk.so.instantiation import NetworkInstantiation, VnfInstantiation
-from onapsdk.exceptions import StatusError, ParameterError
+from onapsdk.utils.jinja import jinja_env
 
 from .instance import Instance
 from .network import NetworkInstance
@@ -152,6 +153,118 @@ class ServiceInstance(Instance):  # pylint: disable=too-many-instance-attributes
                                            f"{self.base_url}{relationship.related_link}"),
                     self)
 
+    @classmethod
+    def create(cls, service_subscription: "ServiceSubscription",  # pylint: disable=too-many-arguments, too-many-locals
+               instance_id: str,
+               instance_name: str = None,
+               service_type: str = None,
+               service_role: str = None,
+               environment_context: str = None,
+               workload_context: str = None,
+               created_at: str = None,
+               updated_at: str = None,
+               resource_version: str = None,
+               description: str = None,
+               model_invariant_id: str = None,
+               model_version_id: str = None,
+               persona_model_version: str = None,
+               widget_model_id: str = None,
+               widget_model_version: str = None,
+               bandwith_total: str = None,
+               vhn_portal_url: str = None,
+               service_instance_location_id: str = None,
+               selflink: str = None,
+               orchestration_status: str = None,
+               input_parameters: str = None):
+        """Service instance creation.
+
+        Args:
+            service_subscription (ServiceSubscription): service subscription which is belongs to
+            instance_id (str): Uniquely identifies this instance of a service
+            instance_name (str, optional): This field will store a name assigned to
+                the service-instance. Defaults to None.
+            service_type (str, optional): String capturing type of service. Defaults to None.
+            service_role (str, optional): String capturing the service role. Defaults to None.
+            environment_context (str, optional): This field will store the environment context
+                assigned to the service-instance. Defaults to None.
+            workload_context (str, optional): This field will store the workload context assigned to
+                the service-instance. Defaults to None.
+            created_at (str, optional): Create time of Network Service. Defaults to None.
+            updated_at (str, optional): Last update of Network Service. Defaults to None.
+            description (str, optional): Short description for service-instance. Defaults to None.
+            model_invariant_id (str, optional): The ASDC model id for this resource or
+                service model. Defaults to None.
+            model_version_id (str, optional): The ASDC model version for this resource or
+                service model. Defaults to None.
+            persona_model_version (str, optional): The ASDC model version for this resource or
+                service model. Defaults to None.
+            widget_model_id (str, optional): The ASDC data dictionary widget model. This maps
+                directly to the A&AI widget. Defaults to None.
+            widget_model_version (str, optional): The ASDC data dictionary version of the widget
+                model. This maps directly to the A&AI version of the widget. Defaults to None.
+            bandwith_total (str, optional): Indicates the total bandwidth to be used for this
+                service. Defaults to None.
+            vhn_portal_url (str, optional): URL customers will use to access the vHN Portal.
+                Defaults to None.
+            service_instance_location_id (str, optional): An identifier that customers assign to
+                the location where this service is being used. Defaults to None.
+            resource_version (str, optional): Used for optimistic concurrency. Must be empty on
+                create, valid on update and delete. Defaults to None.
+            selflink (str, optional): Path to the controller object. Defaults to None.
+            orchestration_status (str, optional): Orchestration status of this service.
+                Defaults to None.
+            input_parameters (str, optional): String capturing request parameters from SO to
+                pass to Closed Loop. Defaults to None.
+        """
+        service_instance: "ServiceInstance" = cls(
+            service_subscription,
+            instance_id,
+            instance_name,
+            service_type,
+            service_role,
+            environment_context,
+            workload_context,
+            created_at,
+            updated_at,
+            resource_version,
+            description,
+            model_invariant_id,
+            model_version_id,
+            persona_model_version,
+            widget_model_id,
+            widget_model_version,
+            bandwith_total,
+            vhn_portal_url,
+            service_instance_location_id,
+            selflink,
+            orchestration_status,
+            input_parameters
+        )
+        cls.send_message("PUT",
+                         f"Create service instance {instance_id} for "\
+                         f"{service_subscription.service_type} service subscription",
+                         f"{service_subscription.url}/service-instances/service-instance/"\
+                         f"{instance_id}",
+                         data=jinja_env()
+                         .get_template("aai_service_instance_create.json.j2")
+                         .render(
+                             service_instance=service_instance
+                         ))
+        return service_instance
+
+    @classmethod
+    def get_all_url(cls, service_subscription: "ServiceSubscription") -> str:  # pylint: disable=arguments-differ
+        """Return an url to get all service instances for service subscription.
+
+        Args:
+            service_subscription (ServiceSubscription): Service subscription object
+
+        Returns:
+            str: Url to get all service instances for service subscription
+
+        """
+        return f"{service_subscription.url}/service-instances/"
+
     @property
     def url(self) -> str:
         """Service instance resource URL.
@@ -214,6 +327,11 @@ class ServiceInstance(Instance):  # pylint: disable=too-many-instance-attributes
             self._sdc_service = Service.get_by_unique_uuid(self.model_invariant_id)
         return self._sdc_service
 
+    @property
+    def active(self) -> bool:
+        """Information if service instance's orchestration status is active."""
+        return self.orchestration_status == "Active"
+
     def add_vnf(self,  # pylint: disable=too-many-arguments
                 vnf: "Vnf",
                 line_of_business: "LineOfBusiness",
@@ -221,7 +339,10 @@ class ServiceInstance(Instance):  # pylint: disable=too-many-instance-attributes
                 cloud_region: "CloudRegion" = None,
                 tenant: "Tenant" = None,
                 vnf_instance_name: str = None,
-                vnf_parameters: Iterable["InstantiationParameter"] = None) -> "VnfInstantiation":
+                vnf_parameters: Iterable["InstantiationParameter"] = None,
+                so_vnf: "SoServiceVnf" = None,
+                a_la_carte: bool = True
+                ) -> "VnfInstantiation":
         """Add vnf into service instance.
 
         Instantiate VNF.
@@ -244,6 +365,8 @@ class ServiceInstance(Instance):  # pylint: disable=too-many-instance-attributes
                 Defaults to None.
             vnf_parameters (Iterable[InstantiationParameter], optional): InstantiationParameter to
                 be passed as "userParams". Defaults to None.
+            so_vnf: (SoServiceVnf, optional): object with vnf instance parameters. Defaults to None.
+            a_la_carte (bool): instantiation type for vnf. Defaults to True.
 
         Raises:
             StatusError: Service orchestration status is not "Active".
@@ -252,12 +375,23 @@ class ServiceInstance(Instance):  # pylint: disable=too-many-instance-attributes
             VnfInstantiation: VnfInstantiation request object
 
         """
-        required_status = "Active"
+        if not self.active:
+            raise StatusError('Service orchestration status must be "Active"')
 
-        if self.orchestration_status != required_status:
-            msg = f'Service orchestration status must be "{required_status}"'
-            raise StatusError(msg)
-        return VnfInstantiation.instantiate_ala_carte(
+        if a_la_carte:
+            return VnfInstantiation.instantiate_ala_carte(
+                self,
+                vnf,
+                line_of_business,
+                platform,
+                cloud_region=cloud_region,
+                tenant=tenant,
+                vnf_instance_name=vnf_instance_name,
+                vnf_parameters=vnf_parameters,
+                sdc_service=self.sdc_service
+            )
+
+        return VnfInstantiation.instantiate_macro(
             self,
             vnf,
             line_of_business,
@@ -266,6 +400,7 @@ class ServiceInstance(Instance):  # pylint: disable=too-many-instance-attributes
             tenant=tenant,
             vnf_instance_name=vnf_instance_name,
             vnf_parameters=vnf_parameters,
+            so_vnf=so_vnf,
             sdc_service=self.sdc_service
         )
 
@@ -305,11 +440,10 @@ class ServiceInstance(Instance):  # pylint: disable=too-many-instance-attributes
             NetworkInstantiation: NetworkInstantiation request object
 
         """
-        required_status = "Active"
-
-        if self.orchestration_status != required_status:
-            msg = f'Service orchestration status must be "{required_status}"'
+        if not self.active:
+            msg = f'Service orchestration status must be "Active"'
             raise StatusError(msg)
+
         return NetworkInstantiation.instantiate_ala_carte(
             self,
             network,
