@@ -7,7 +7,7 @@ from onapsdk.msb.multicloud import Multicloud
 from onapsdk.utils.jinja import jinja_env
 from onapsdk.exceptions import ResourceNotFound
 
-from ..aai_element import AaiElement, Relationship
+from ..aai_element import AaiResource, Relationship
 from .complex import Complex
 from .tenant import Tenant
 
@@ -52,7 +52,7 @@ class EsrSystemInfo:  # pylint: disable=too-many-instance-attributes
     openstack_region_id: str = None
 
 
-class CloudRegion(AaiElement):  # pylint: disable=too-many-instance-attributes
+class CloudRegion(AaiResource):  # pylint: disable=too-many-instance-attributes
     """Cloud region class.
 
     Represents A&AI cloud region object.
@@ -127,6 +127,16 @@ class CloudRegion(AaiElement):  # pylint: disable=too-many-instance-attributes
             f"CloudRegion(cloud_owner={self.cloud_owner}, cloud_region_id={self.cloud_region_id})"
         )
 
+    @classmethod
+    def get_all_url(cls) -> str:  # pylint: disable=arguments-differ
+        """Return url to get all cloud regions.
+
+        Returns:
+            str: Url to get all cloud regions
+
+        """
+        return f"{cls.base_url}{cls.api_version}/cloud-infrastructure/cloud-regions"
+
     @classmethod
     def get_all(cls,
                 cloud_owner: str = None,
@@ -152,8 +162,7 @@ class CloudRegion(AaiElement):  # pylint: disable=too-many-instance-attributes
                 "owner-defined-type": owner_defined_type,
             }
         )
-        url: str = (f"{cls.base_url}{cls.api_version}/cloud-infrastructure/"
-                    f"cloud-regions?{urlencode(filter_parameters)}")
+        url: str = (f"{cls.get_all_url()}?{urlencode(filter_parameters)}")
         response_json: Dict[str, List[Dict[str, Any]]] = cls.send_message_json(
             "GET", "get cloud regions", url
         )
@@ -422,6 +431,19 @@ class CloudRegion(AaiElement):  # pylint: disable=too-many-instance-attributes
             resource_version=response.get("resource-version"),
         )
 
+    def get_tenants_by_name(self, tenant_name: str) -> Iterator["Tenant"]:
+        """Get tenants with given name.
+
+        Args:
+            tenant_name (str): Tenant name
+
+        Returns:
+            Iterator[Tenant]: Iterate through cloud region tenants with given name
+
+        """
+        return (tenant for tenant in self.tenants if tenant.name == tenant_name)
+
+
     def get_availability_zone_by_name(self,
                                       zone_name: str) -> "AvailabilityZone":
         """Get availability zone with provided Name.
