@@ -125,7 +125,7 @@ class Service(SdcResource):  # pylint: disable=too-many-instance-attributes, too
                  inputs: List[Union[Property, NestedInput]] = None,
                  instantiation_type: Optional[ServiceInstantiationType] = \
                      None,
-                 category: str = None):
+                 category: str = None, role: str = "", function: str = "", service_type: str = ""):
         """
         Initialize service object.
 
@@ -143,6 +143,9 @@ class Service(SdcResource):  # pylint: disable=too-many-instance-attributes, too
             instantiation_type (ServiceInstantiationType, optional): service instantiation
                 type. ServiceInstantiationType.A_LA_CARTE by default
             category (str, optional): service category name
+            role (str, optional): service role
+            function (str, optional): service function. Empty by default
+            service_type (str, optional): service type. Empty by default
 
         """
         super().__init__(sdc_values=sdc_values, version=version, properties=properties,
@@ -150,6 +153,9 @@ class Service(SdcResource):  # pylint: disable=too-many-instance-attributes, too
         self.name: str = name or "ONAP-test-Service"
         self.distribution_status = None
         self.category_name: str = category
+        self.role: str = role
+        self.function: str = function
+        self.service_type: str = service_type
         if sdc_values:
             self.distribution_status = sdc_values['distributionStatus']
             self.category_name = sdc_values["category"]
@@ -332,8 +338,41 @@ class Service(SdcResource):  # pylint: disable=too-many-instance-attributes, too
                         ))
         return node_template
 
+    def __has_component_type(self, origin_type: str) -> bool:
+        """Check if any of Service's component type is provided origin type.
+
+        In template generation is checked if Service has some types of components,
+            based on that blocks are added to the request template. It's not
+            the best option to get all components to check if at least one with
+            given type exists for conditional statement.
+
+        Args:
+            origin_type (str): Type to check if any component exists.
+
+        Returns:
+            bool: True if service has at least one component with given origin type,
+                False otherwise
+
+        """
+        return any((component.origin_type == origin_type for component in self.components))
+
     @property
-    def vnfs(self) -> List[Vnf]:
+    def has_vnfs(self) -> bool:
+        """Check if service has at least one VF component."""
+        return self.__has_component_type("VF")
+
+    @property
+    def has_pnfs(self) -> bool:
+        """Check if service has at least one PNF component."""
+        return self.__has_component_type("PNF")
+
+    @property
+    def has_vls(self) -> bool:
+        """Check if service has at least one VL component."""
+        return self.__has_component_type("VL")
+
+    @property
+    def vnfs(self) -> Iterator[Vnf]:
         """Service Vnfs.
 
         Load VNFs from components generator.
@@ -483,7 +522,8 @@ class Service(SdcResource):  # pylint: disable=too-many-instance-attributes, too
         self._create("service_create.json.j2",
                      name=self.name,
                      instantiation_type=self.instantiation_type.value,
-                     category=self.category)
+                     category=self.category,
+                     role=self.role, service_type=self.service_type, function=self.function)
 
     def declare_resources_and_properties(self) -> None:
         """Delcare resources and properties.
@@ -534,6 +574,13 @@ class Service(SdcResource):  # pylint: disable=too-many-instance-attributes, too
                                        const.DISTRIBUTE,
                                        headers=headers)
 
+    def redistribute(self) -> None:
+        """Apptove Service in SDC."""
+        headers = headers_sdc_creator(SdcResource.headers)
+        self._verify_distribute_to_sdc(const.DISTRIBUTED,
+                                       const.DISTRIBUTE,
+                                       headers=headers)
+
     def get_tosca(self) -> None:
         """Get Service tosca files and save it."""
         url = "{}/services/{}/toscaModel".format(self._base_url(),
@@ -655,6 +702,7 @@ class Service(SdcResource):  # pylint: disable=too-many-instance-attributes, too
         """
         super()._specific_copy(obj)
         self.category_name = obj.category_name
+        self.role = obj.role
 
     def _verify_distribute_to_sdc(self, desired_status: str,
                                   desired_action: str, **kwargs) -> None:
